TheAvengersModels class

Constructors

TheAvengersModels({int? id, String? name, String? fullName, String? email, String? gender, String? isCanSwim, dynamic isCanFly, int? status, String? createdAt})
TheAvengersModels.fromMap(Map<String, dynamic> map)

Properties

createdAt String?
getter/setter pair
email String?
getter/setter pair
fullName String?
getter/setter pair
gender String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id int?
getter/setter pair
isCanFly String?
getter/setter pair
isCanSwim String?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited