DatabaseService class

Constructors

DatabaseService()

Properties

database Future<Database>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteAvenger(int id, TheAvengersModels model) Future<int>
getAvengers() Future<List<TheAvengersModels>?>
getSingleAvenger(int id) Future<TheAvengersModels?>
initDatabase() → dynamic
insertAvenger(TheAvengersModels model) Future<int>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateAvenger(int id, TheAvengersModels model) Future<int>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DatabaseService
final